modifier

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2021 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package modifier exposes a request modifier for generating parametrized queries to an elastic search service

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FromJSON

func FromJSON(b []byte) (*parse.Result, error)

Types

type ESQueryModifier

type ESQueryModifier struct {
	Keys []string `json:"keys"`
}

func (*ESQueryModifier) ModifyRequest

func (m *ESQueryModifier) ModifyRequest(req *http.Request) error

ModifyRequest modifies the query string of the request with the given key and value.

type Query

type Query struct {
	Match map[string]string `json:"match"`
}
type Search struct {
	Query Query `json:"query"`
}

Jump to