Documentation
¶
Overview ¶
Package modifier exposes a request modifier for generating parametrized queries to an elastic search service
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ESQueryModifier ¶
type ESQueryModifier struct {
Keys []string `json:"keys"`
}
func (*ESQueryModifier) ModifyRequest ¶
func (m *ESQueryModifier) ModifyRequest(req *http.Request) error
ModifyRequest modifies the query string of the request with the given key and value.
Click to show internal directories.
Click to hide internal directories.